from django.core.management.base import CommandError
from apella.models import ApellaUser, Position, Candidacy
from apella.management.utils import get_user, ApellaCommand


class Command(ApellaCommand):
    help = 'Create a candidacy for a position for the given user'

    def add_arguments(self, parser):
        parser.add_argument('position_id')
        parser.add_argument('candidate_id_or_username')

    def handle(self, *args, **options):
        position_id = options['position_id']
        candidate_id = options['candidate_id_or_username']

        try:
            position = Position.objects.get(id=position_id)
            candidate = get_user(candidate_id)
            c = Candidacy.objects.create(
                position=position, candidate=candidate)
            code = c.pk
            c.code = code
            c.save()
            self.stdout.write(
                "Created candidacy %s : candidate = %s position = %s" %
                (c.pk, c.candidate.username, c.position.id))
        except ValueError:
            raise CommandError("Position id and candidate id must be integers")
        except Position.DoesNotExist:
            raise CommandError("Position %s does not exist" % position_id)
        except ApellaUser.DoesNotExist:
            raise CommandError("User %s does not exist" % candidate_id)
