from django.core.management.base import BaseCommand, CommandError
from apella.management.utils import ApellaCommand
from apella.models import Department, School, Institution,\
    MultiLangFields


class Command(ApellaCommand):
    help = 'Create a department for the given school'

    def add_arguments(self, parser):
        parser.add_argument('institution_id')
        parser.add_argument('school_id')
        parser.add_argument('title_el')

        parser.add_argument('--en',
            action='store_true',
            dest='en',
            default=False,
            help="Department title in english")

    def handle(self, *args, **options):
        institution_id = options['institution_id']
        school_id = options['school_id']
        title_el = options['title_el']

        title_en = options['en']

        try:
            title = MultiLangFields.objects.create(
                    el=title_el, en=title_en)
            institution = Institution.objects.get(id=institution_id)
            school = School.objects.get(id=school_id)
            department = Department.objects.create(
                                            institution=institution,
                                            school=school,
                                            title=title,
                                            dep_number=20)
            self.stdout.write(
                "Created department %s : %s" %
                (department.pk, department.title.el))
        except School.DoesNotExist:
            raise CommandError("School %s does not exist" % school_id)
        except Institution.DoesNotExist:
            raise CommandError(
                "Institution %s does not exist" % institution_id)
        except BaseException, e:
            raise CommandError(e)
