from django.core.management.base import BaseCommand, CommandError
from apella.models import InstitutionManager, Institution, ApellaUser
from apella import common
from apella.management.utils import get_user, ApellaCommand


class Command(ApellaCommand):
    help = 'Create an institution manager'

    def add_arguments(self, parser):
        parser.add_argument('user_id_or_username')
        parser.add_argument('institution_id')

        parser.add_argument('--role',
            action='store_true',
            dest='role',
            default='institutionmanager',
            help='Choose a role for the user')


    def handle(self, *args, **options):
        user_id_or_username = options['user_id_or_username']
        institution_id = options['institution_id']

        try:
            user = get_user(user_id_or_username)
            institution = Institution.objects.get(id=institution_id)
            a = InstitutionManager.objects.create(
                user=user,
                institution=institution,
                is_verified=True,
                manager_role=options['role'])

            self.stdout.write("InstitutionManager with id: %s created" % a.pk)
        except ApellaUser.DoesNotExist:
            raise CommandError("User %s does not exist" % user_id_or_username)
        except Institution.DoesNotExist:
            raise CommandError(
                "Institution %s does not exist" % institution_id)
