from django.core.management.base import BaseCommand, CommandError
from apella.models import Position


class Command(BaseCommand):
    help = 'Post a position'

    def add_arguments(self, parser):
        parser.add_argument('position_id')
        parser.add_argument('--start',
            action='store_true',
            dest='starts_at',
            help='The date and time the position starts accepting' +
            ' candidacies.'),
        parser.add_argument('--end',
            action='store_true',
            dest='ends_at',
            help='The date and time the position stops accepting' +
            ' candidacies.'),

    def handle(self, *args, **options):
        position_id = options['position_id']
        starts_at = options['starts_at']
        ends_at = options['ends_at']

        try:
            position = Position.objects.get(id=position_id)
            position.starts_at = starts_at
            position.ends_at = ends_at
            position.state = '2'
            position.save()
            self.stdout.write("Posted position %s" % position_id)
        except ValueError:
            raise CommandError("Position id must be an integer")
        except Position.DoesNotExist:
            raise CommandError("Position %s does not exist" % position_id)
