from django.core.management.base import BaseCommand, CommandError
from apella.management.utils import ApellaCommand
from apella.models import SubjectArea, Subject, MultiLangFields


class Command(ApellaCommand):
    help = 'Create a subject'

    def add_arguments(self, parser):
        parser.add_argument('subject_area_id')
        parser.add_argument('el')
        parser.add_argument('en')

    def handle(self, *args, **options):
        subject_area_id = options['subject_area_id']
        title_el = options['el']
        title_en = options['en']

        try:
            subject_area = SubjectArea.objects.get(id=subject_area_id)
            title = MultiLangFields.objects.create(
                    el=title_el, en=title_en)
            subject = Subject.objects.create(area=subject_area, title=title)

            self.stdout.write(
                    "Created subject %s : %s, area : %s" %
                    (subject.pk, subject.title.el, subject.area.title.el))
        except SubjectArea.DoesNotExist:
            raise CommandError(
                "Subject area %s does not exist" % subject_area_id)
        except ValueError:
            raise CommandError(
                "Expected integer for <subject area id>, got: %s" %
                subject_area_id)
        except:
            raise
